@@ -2,11 +2,16 @@
 Router imports
 """
 
+from . import caption
 from . import embeddings
+from . import entity
 from . import extractor
+from . import labels
+from . import objects
 from . import segmentation
 from . import similarity
 from . import summary
+from . import tabular
 from . import textractor
 from . import transcription
 from . import translation
