@@ -25,39 +25,39 @@ class StorageTask(Task):
     PREFIX = r"(\w+):\/\/.*"
     PATH = r"\w+:\/\/(.*)"
 
-    def __init__(self, action=None, select=None, unpack=True, ids=True):
+    def register(self):
+        """
+        Checks if required dependencies are installed.
+        """
+
         if not LIBCLOUD:
             raise ImportError('StorageTask is not available - install "workflow" extra to enable')
 
-        super().__init__(action, select, unpack)
-
-        # If true, elements returned will be tagged with ids and converted into (id, data, tag) tuples
-        self.ids = ids
-
-    def accept(self, element):
-        # Only accept file URLs
-        return super().accept(element) and re.match(StorageTask.PREFIX, element.lower())
-
-    def execute(self, elements):
-        # List contents of each bucket
-        buckets = [self.list(element) for element in elements]
-
-        elements = []
-        for bucket in buckets:
-            # Execute actions
-            content = super().execute(bucket)
-
-            # Combine with content ids if necessary
-            if self.ids:
-                values = []
-                for x, url in enumerate(bucket):
-                    values.append((url, content[x], None))
+    def __call__(self, elements, executor=None):
+        # Create aggregated directory listing for all elements
+        outputs = []
+        for element in elements:
+            if self.matches(element):
+                # Get directory listing and run actions
+                outputs.extend(super().__call__(self.list(element), executor))
             else:
-                values = content
+                outputs.append(element)
 
-            elements.append(values)
+        return outputs
 
-        return elements
+    def matches(self, element):
+        """
+        Determines if this element is a storage element.
+
+        Args:
+            element: input storage element
+
+        Returns:
+            True if this is a storage element
+        """
+
+        # Only accept file URLs
+        return re.match(StorageTask.PREFIX, self.upack(element, True).lower())
 
     def list(self, element):
         """
